.not-logged-in-wrapper {
  padding-top: 3em;

  h1 {
    text-indent: -10000px;
    max-height: 55px;
    margin: 0;
    background: url(../../images/logo.svg) no-repeat;
  }

  h2 { font-size: 2rem; }

  .about {
    &, a { color: lighten($text-color, 40%); }
    a:hover { color: $text-color; };
    padding-top: 2em;
  }
}
