$body-bg: #fafafa !default;
$sidebar-bg: darken(#fff, 4%) !default;
$primary-color: lighten(#2c5e2e, 10%) !default;
$secondary-color: #2c5e2e !default;
$header-color: lighten($primary-color, 5%) !default;
$link-color: lighten($primary-color, 0%) !default;
$text-color: #222 !default;
$paste-bg-color: #f8f8f8 !default;

$font-family-default: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif !default;
$font-family-monospace: "SFMono-Regular", Consolas, "Liberation Mono", Menlo, monospace !default;

$collection-border-color: darken($body-bg, 9%) !default;

$error-bg-color: color('red', 'lighten-5') !default;
$error-border-color: color('red', 'lighten-2') !default;
$error-text-color: color("red", "darken-4") !default;
$highlight-bg-color: lighten(color("red", "lighten-4"), 2%) !default;
$notice-text-color: lighten($text-color, 40%) !default;
$notice-border-color: color('grey', 'lighten-1') !default;
$settings-active-color: #f6f6f6 !default;

$readable-width: 50em !default;
$main-menu-width: 240px !default;
$sidebar-width: 320px !default;
$z-index-header: 900 !default;

$input-height: 2.8rem !default;
$input-disabled-color: rgba(0, 0, 0, .50) !default;
$button-floating-background: lighten($primary-color, 5%) !default;
$button-floating-background-hover: $primary-color !default;
