<template>
  <ul>
    <li><a target="_blank" href="http://convos.by">Project homepage</a></li>
    <li><a target="_blank" href="https://github.com/Nordaaker/convos/issues">Bug/issue tracker</a></li>
    <li><a target="_blank" href="https://github.com/Nordaaker/convos">Source code</a></li>
  </ul>
  <p>
    Wanna talk to us? Join the "#convos" channel on
    <a target="_blank" href="http://freenode.net/">irc.freenode.net</a>.
  </p>
  <p>
    Version <a target="_blank" href="https://github.com/Nordaaker/convos/tree/{{settings.version}}">{{settings.version}}</a>
  </p>
</template>
<script>
module.exports = {};
</script>
