html, body {
  font-family: $font-family-default;
  background-color: $body-bg;
  color: $text-color;
}

h1, h2, h3, h4, h5 {
  color: $header-color;
}

strong { font-weight: bold; }

p {
  margin: 1rem 0;
}

dl {
  dt { margin: 0; }
  dd { margin: 0 0 0.5rem 1rem; }
}

pre {
  margin: 0;
  padding: 0;
}

pre.stylish {
  padding: 0.2rem 0.5rem;
  background: darken($body-bg, 4%);
  margin: 0.3rem 0;
}

dl.horizontal {
  margin: 0;
  dt {
    width: 10em;
    float: left;
    clear: left;
  }
}

a:hover {
  color: darken($secondary-color, 10%);
}

svg {
  width: 100%;
  height: auto;
  display: inline-block;
}

iframe {
  display: block;
}

button.btn[disabled] {
  @extend .disabled;
}

div.alert, p.alert {
  background: $error-bg-color;
  border: 1px solid $error-border-color;
  border-radius: 2px;
  color: color('red', 'darken-2');
  padding: $card-padding / 2;

  a {
    color: color('red', 'darken-3');
    text-decoration: underline;

    &:hover {
      text-decoration: none;
    }
  }
}

.btn-delete {
  @extend .btn, .waves-effect, .waves-light, .red, .darken-2;
}

.col {
  .btn, .btn-large, .btn-flat {
    margin-right: 0.5rem;
    &.right { margin-right: 0; }
  }
}

.hidden { display: none; }

.input-btn-right {
  .btn {
    float: right;
    margin-right: 0;
    margin-top: 0.5rem;
  }
  .input-left {
    overflow: hidden;
    padding-right: $gutter-width / 2;
  }
}

.select-wrapper {
  ul {
    display: block;
    margin-top: -54px;
    transition: opacity 0.3s ease-in-out;
    left: -2000px;
    &.active { opacity: 1; left: auto; }
  }

  input.select-dropdown {
    color: $text-color;
  }
}

.dropdown-content li {
  &:hover { background: $dropdown-hover-bg-color; }
  &.disabled:hover { background: transparent; }
  &.active { background: darken($dropdown-hover-bg-color, 5%); }
}

#vue_tooltip {
  background-color: #323232;
  color: #fefefe;
  font-size: 1rem;
  line-height: 120%;
  text-align: center;

  border-radius: 4px;
  padding: 8px 6px;
  max-width: calc(100% - 4px);
  min-height: 30px;

  transition: opacity 350ms;
  transition-delay: 100ms;

  position: absolute;
  left: -2000px;
  top: -2000px;
  overflow: hidden;
  opacity: 0;
  z-index: 2000;
  will-change: opacity;
  pointer-events: none;

  &.active { opacity: 0.95; }

  @media #{$medium-and-down} {
    display: none !important;
  }
}

.scroll-element {
  height: 100%;
  overflow: auto;
}
