.convos-create-dialog .autocomplete {
  a {
    padding: 0.3rem 0;
    border-bottom: 1px solid $dropdown-hover-bg-color;
    display: block;

    &:hover { background-color: $dropdown-hover-bg-color; }
    &.active { background-color: darken($dropdown-hover-bg-color, 5%); }
  }

  h6 {
    color: $link-color;
    display: block;
    margin: 0;
    font-weight: bold;
  }

  p {
    color: lighten($text-color, 15%);
    font-size: 0.9rem;
    margin-top: 0.3rem;
  }

  .badge .material-icons {
    font-size: 1.1em;
    vertical-align: middle;
  }
}

ul.complete-dropdown {
  margin: 0;
  position: absolute;
  display: block !important;
  opacity: 1 !important;
  max-height: 50vh;

  li { min-height: auto; }
  li:hover { background: transparent; }
  li.active:hover { background: $dropdown-hover-bg-color; }
  li > a { padding: 6px 16px; cursor: default; }
}
