.le-rich,
.le-photo {
  overflow: hidden;
  display: block;
  max-width: 100%; // required to contain iframes on iphone
  max-height: 20rem;
  margin: 6px 0;

  @media #{$medium-and-up} {
    max-height: none;
  }
}

blockquote.le-card,
div.le-card {
  background: darken($body-bg, 3%);
  border: 1px solid darken($body-bg, 10%);
  padding: 0.5rem;
  margin: 0.3rem 0;
}

.le-card,
.le-rich {
  .le-thumbnail-placeholder {
    display: none;
  }
  .le-thumbnail, {
    float: left;
    img {
      max-height: 50px;
      margin-right: 8px;
      border: 0;
      box-shadow: none;
      vertical-align: bottom;
    }
  }

  h3 {
    font-size: 1em;
    line-height: 1em;
    display: block;
    margin: 0;
  }

  p {
    font-size: 0.9em;
    line-height: 1.2em;
    margin: 4px 0;
    display: table-cell;
  }
}

.le-provider-link ~ .le-goto-link:before,
.le-author-link ~ .le-goto-link:before {
  content: "\2013\00a0";
}

.le-paste .le-provider-link:before {
  content: "Hosted by ";
}

.le-video video {
  background: darken($body-bg, 3%);
  border: 1px solid darken($body-bg, 10%);
  display: block;
  width: 100%;
  height: auto;
}

.le-image-card .le-goto-link {
  display: none;
}

.le-photo img {
  max-height: 220px;
}

.materialboxed {
  cursor: zoom-in;
  border-radius: 2px;
  transition: box-shadow .3s;
  box-shadow: none;

  &:hover {
    box-shadow: 0 3px 7px 0 rgba(0, 0, 0, 0.2);
  }
}

.materialbox-overlay {
  background-color: #292929;
  width: 0;
  overflow: hidden;
  position: fixed;
  bottom: 0;
  left: 0;
  top: 0;
  z-index: 1001;
  opacity: 0.01;
  cursor: zoom-out;

  img {
    transition:
      width .3s ease-in-out,
      height .3s ease-in-out,
      left .3s ease-in-out,
      top .3s ease-in-out;
  }

  &.active {
    display: block;
    opacity: 0.98;
    width: 100%;
  }
}

.hljs {
  font-family: $font-family-monospace;
  font-size: 0.9rem;
  line-height: 1.3rem;
  white-space: pre;
}

.le-paste {
  background: $paste-bg-color;
  border: 1px solid darken($paste-bg-color, 10%);
  max-height: 80px;
  max-width: 100%;
  overflow: hidden;

  .le-meta {
    background-color: darken($paste-bg-color, 10%);
    color: $text-color;
    padding: 0.2em 0.5rem;
    margin: 0;
    cursor: zoom-in;

    &::before {
      @extend .material-icons;
      font-size: 1.6rem !important;
      content: '\e313';
      float: right;
    }
  }

  ol {
    margin: 0.2rem 0;
  }

  &.expanded {
    max-height: none;
    overflow-x: auto;

    .le-meta {
      cursor: zoom-out;
      &::before {
        content: '\e316';
      }
    }
  }
}

div.paste {
  margin-bottom: 3rem;
  border-bottom: 1px solid darken($paste-bg-color, 10%);

  h1 { font-size: 2rem; }
}
