@mixin input-placeholder-color($color) {
  ::-webkit-input-placeholder { color: $color; }
  :-moz-placeholder { color: $color; }
  ::-moz-placeholder { color: $color; }
  :-ms-input-placeholder { color: $color; }
}

@mixin overflow() {
  -webkit-overflow-scrolling: touch;
  overflow: auto;
}

@mixin progress-bar($bg, $bgShade) {
  background: repeating-linear-gradient(-45deg, $bg, $bg 10px, $bgShade 10px, $bgShade 20px, $bg 20px) top left;
  background-position: 0 0;
  background-size: 394px 100%;
  animation: background-position 14s infinite linear;
}

@keyframes background-position {
  0% { background-position: 0 0; }
  100% { background-position: 100% 0; }
}
