! convos.css
<< https://raw.githubusercontent.com/Dogfalo/materialize/master/sass/materialize.scss
< http://cdn.jsdelivr.net/emojione/2.2.6/assets/css/emojione.min.css
< sass/main.scss

! convos.js
< http://code.jquery.com/jquery-3.3.1.min.js
< http://vuejs.org/js/vue.js
< http://cdn.jsdelivr.net/emojione/2.2.6/lib/js/emojione.min.js
< https://cdnjs.cloudflare.com/ajax/libs/highlight.js/9.9.0/highlight.min.js
< js/autolink.js
< js/eventemitter.js
< js/window.js
< js/string.js
< js/url.js
< js/notification.js
< js/materialbox.js
< js/openapi.js
< js/vue/directive-link.js
< js/vue/directive-sidebar.js
< js/vue/directive-tooltip.js
< js/vue/filter-timestring.js
< js/vue/mixin-autocomplete.js
< js/vue/mixin-global.js
< js/vue/mixin-message.js
< js/vue/mixin-messages.js

< https://raw.githubusercontent.com/jackmoore/autosize/master/dist/autosize.min.js
< https://raw.githubusercontent.com/Dogfalo/materialize/master/js/velocity.min.js
< https://raw.githubusercontent.com/Dogfalo/materialize/master/js/waves.js
< https://raw.githubusercontent.com/Dogfalo/materialize/master/js/jquery.easing.1.3.js
< https://raw.githubusercontent.com/Dogfalo/materialize/master/js/global.js
< https://raw.githubusercontent.com/Dogfalo/materialize/master/js/animation.js

< js/core/commands.js
< js/core/connection.js
< js/core/dialog.js
< js/core/user.js

# materialize elements
< vue/md-input.vue
< vue/md-option.vue
< vue/md-select.vue
< vue/md-textarea.vue

# sidebars
< vue/convos-main-menu.vue
< vue/convos-help.vue
< vue/convos-resources.vue
< vue/convos-notifications.vue
< vue/convos-connection-settings.vue
< vue/convos-dialog-settings.vue
< vue/convos-sidebar-info.vue
< vue/convos-profile.vue

# chat
< vue/convos-message-action.vue
< vue/convos-message-day-changed.vue
< vue/convos-message-enable-notifications.vue
< vue/convos-message-error.vue
< vue/convos-message-notice.vue
< vue/convos-message-participants.vue
< vue/convos-message-password.vue
< vue/convos-message-private.vue
< vue/convos-message-whois.vue
< vue/convos-input.vue
< vue/convos-dialog-container.vue

# settings
< vue/convos-create-dialog.vue
< vue/convos-settings.vue

# main components
< vue/convos-chat.vue
< vue/convos-not-logged-in.vue
< vue/convos-login.vue
< vue/convos-recover.vue
< vue/convos-register.vue

< js/main.js
